@@ -66,9 +66,9 @@ async def put_object(bucket_name: str, path: str, data: io.BytesIO, length: int,
 
             await s3_client.put_object(Bucket=bucket_name, Key=path, Body=data, ContentLength=length)
 
-            logger.debug(f'Stored object into object storage: {bucket_name}:{path}')
+            logger.debug('Stored object into object storage: %s:%s', bucket_name, path)
         except Exception as e:
-            logger.exception(f'Failed to put object to object storage: {bucket_name}:{path}', exc_info=e)
+            logger.exception('Failed to put object to object storage: %s:%s', bucket_name, path, exc_info=e)
 
             raise
 
@@ -80,7 +80,7 @@ async def get_object_stream(bucket_name: str, path: str) -> AsyncGenerator[Strea
     storage = ObjectStorage(s3_settings)
 
     async with storage.get_client() as s3_client:
-        logger.debug(f'Getting object from object storage: {bucket_name}:{path}')
+        logger.debug('Getting object from object storage: %s:%s', bucket_name, path)
 
         try:
             response = await s3_client.get_object(Bucket=bucket_name, Key=path)
@@ -88,7 +88,7 @@ async def get_object_stream(bucket_name: str, path: str) -> AsyncGenerator[Strea
             async with response['Body'] as stream:
                 yield stream
         except Exception as e:
-            logger.exception(f'Failed getting object from object storage: {bucket_name}:{path}', exc_info=e)
+            logger.exception('Failed getting object from object storage: %s:%s', bucket_name, path, exc_info=e)
 
             raise
 
@@ -97,7 +97,7 @@ async def get_object(bucket_name: str, path: str) -> bytes:
     async with get_object_stream(bucket_name, path) as stream:
         body = await stream.read()
 
-    logger.debug(f'Loaded object from object storage: {bucket_name}:{path}')
+    logger.debug('Loaded object from object storage: %s:%s', bucket_name, path)
 
     return body
 
@@ -142,9 +142,9 @@ async def remove_object(bucket_name: str, object_name: str) -> None:
     async with storage.get_client() as s3_client:
         try:
             await s3_client.delete_object(Bucket=bucket_name, Key=object_name)
-            logger.debug(f'Removed object from object storage: {bucket_name}:{object_name}')
+            logger.debug('Removed object from object storage: %s:%s', bucket_name, object_name)
         except Exception as e:
-            logger.exception(f'Failed to remove object from object storage: {bucket_name}:{object_name}', exc_info=e)
+            logger.exception('Failed to remove object from object storage: %s:%s', bucket_name, object_name, exc_info=e)
 
             raise
 
@@ -180,9 +180,9 @@ async def remove_objects(
                 if 'Errors' in response:
                     errors.extend(response['Errors'])
 
-            logger.debug(f'Removed {len(objects_to_delete)} objects from object storage: {bucket_name}')
+            logger.debug('Removed %d objects from object storage: %s', len(objects_to_delete), bucket_name)
         except Exception as e:
-            logger.exception(f'Failed to remove objects from object storage: {bucket_name}', exc_info=e)
+            logger.exception('Failed to remove objects from object storage: %s', bucket_name, exc_info=e)
 
             raise
 
